@@ -148,7 +148,7 @@ ags_ramp_acceleration_dialog_class_init(AgsRampAccelerationDialogClass *ramp_acc
    *
    * The assigned #AgsApplicationContext to give control of application.
    * 
-   * Since: 0.9.29
+   * Since: 1.0.0
    */
   param_spec = g_param_spec_object("application-context",
 				   i18n_pspec("assigned application context"),
@@ -164,7 +164,7 @@ ags_ramp_acceleration_dialog_class_init(AgsRampAccelerationDialogClass *ramp_acc
    *
    * The assigned #AgsWindow.
    * 
-   * Since: 0.9.29
+   * Since: 1.0.0
    */
   param_spec = g_param_spec_object("main-window",
 				   i18n_pspec("assigned main window"),
@@ -243,6 +243,8 @@ ags_ramp_acceleration_dialog_init(AgsRampAccelerationDialog *ramp_acceleration_d
   ramp_acceleration_dialog->ramp_x0 = (GtkSpinButton *) gtk_spin_button_new_with_range(0.0,
 										       AGS_RAMP_ACCELERATION_MAX_BEATS,
 										       0.25);
+  gtk_spin_button_set_digits(ramp_acceleration_dialog->ramp_x0,
+			     2);
   gtk_spin_button_set_value(ramp_acceleration_dialog->ramp_x0,
 			    0.0);
   gtk_box_pack_start((GtkBox *) hbox,
@@ -293,6 +295,8 @@ ags_ramp_acceleration_dialog_init(AgsRampAccelerationDialog *ramp_acceleration_d
   ramp_acceleration_dialog->ramp_x1 = (GtkSpinButton *) gtk_spin_button_new_with_range(0.0,
 										       AGS_RAMP_ACCELERATION_MAX_BEATS,
 										       0.25);
+  gtk_spin_button_set_digits(ramp_acceleration_dialog->ramp_x1,
+			     2);
   gtk_spin_button_set_value(ramp_acceleration_dialog->ramp_x1,
 			    0.0);
   gtk_box_pack_start((GtkBox *) hbox,
@@ -833,7 +837,7 @@ ags_ramp_acceleration_dialog_delete_event(GtkWidget *widget, GdkEventAny *event)
  *
  * Returns: a new #AgsRampAccelerationDialog
  *
- * Since: 0.9.29
+ * Since: 1.0.0
  */
 AgsRampAccelerationDialog*
 ags_ramp_acceleration_dialog_new(GtkWidget *main_window)
