@@ -148,7 +148,7 @@ ags_select_acceleration_dialog_class_init(AgsSelectAccelerationDialogClass *sele
    *
    * The assigned #AgsApplicationContext to give control of application.
    * 
-   * Since: 0.9.29
+   * Since: 1.0.0
    */
   param_spec = g_param_spec_object("application-context",
 				   i18n_pspec("assigned application context"),
@@ -164,7 +164,7 @@ ags_select_acceleration_dialog_class_init(AgsSelectAccelerationDialogClass *sele
    *
    * The assigned #AgsWindow.
    * 
-   * Since: 0.9.29
+   * Since: 1.0.0
    */
   param_spec = g_param_spec_object("main-window",
 				   i18n_pspec("assigned main window"),
@@ -260,6 +260,8 @@ ags_select_acceleration_dialog_init(AgsSelectAccelerationDialog *select_accelera
   select_acceleration_dialog->select_x0 = (GtkSpinButton *) gtk_spin_button_new_with_range(0.0,
 											   AGS_SELECT_ACCELERATION_MAX_BEATS,
 											   0.25);
+  gtk_spin_button_set_digits(select_acceleration_dialog->select_x0,
+			     2);
   gtk_spin_button_set_value(select_acceleration_dialog->select_x0,
 			    0.0);
   gtk_box_pack_start((GtkBox *) hbox,
@@ -285,6 +287,8 @@ ags_select_acceleration_dialog_init(AgsSelectAccelerationDialog *select_accelera
   select_acceleration_dialog->select_x1 = (GtkSpinButton *) gtk_spin_button_new_with_range(0.0,
 											   AGS_SELECT_ACCELERATION_MAX_BEATS,
 											   0.25);
+  gtk_spin_button_set_digits(select_acceleration_dialog->select_x1,
+			     2);
   gtk_spin_button_set_value(select_acceleration_dialog->select_x1,
 			    0.0);
   gtk_box_pack_start((GtkBox *) hbox,
@@ -746,7 +750,7 @@ ags_select_acceleration_dialog_delete_event(GtkWidget *widget, GdkEventAny *even
  *
  * Returns: a new #AgsSelectAccelerationDialog
  *
- * Since: 0.9.29
+ * Since: 1.0.0
  */
 AgsSelectAccelerationDialog*
 ags_select_acceleration_dialog_new(GtkWidget *main_window)
