@@ -39,12 +39,25 @@
 typedef struct _AgsPulsePort AgsPulsePort;
 typedef struct _AgsPulsePortClass AgsPulsePortClass;
 
+/**
+ * AgsPulsePortFlags:
+ * @AGS_PULSE_PORT_CONNECTED: indicates the port was connected by calling #AgsConnectable::connect()
+ * @AGS_PULSE_PORT_REGISTERED: the port was registered
+ * @AGS_PULSE_PORT_IS_AUDIO: the port provides audio data
+ * @AGS_PULSE_PORT_IS_MIDI: the port provides midi data
+ * @AGS_PULSE_PORT_IS_OUTPUT: the port does output
+ * @AGS_PULSE_PORT_IS_INPUT: the port does input
+ * 
+ * Enum values to control the behavior or indicate internal state of #AgsPulsePort by
+ * enable/disable as flags.
+ */
 typedef enum{
   AGS_PULSE_PORT_CONNECTED       = 1,
   AGS_PULSE_PORT_REGISTERED      = 1 <<  1,
   AGS_PULSE_PORT_IS_AUDIO        = 1 <<  2,
   AGS_PULSE_PORT_IS_MIDI         = 1 <<  3,
   AGS_PULSE_PORT_IS_OUTPUT       = 1 <<  4,
+  AGS_PULSE_PORT_IS_INPUT        = 1 <<  5,
 }AgsPulsePortFlags;
 
 struct _AgsPulsePort
