@@ -46,6 +46,8 @@
 #include <libxml/xmlmemory.h>
 #include <libxml/xmlsave.h>
 
+#include <ags/i18n.h>
+
 void ags_file_class_init(AgsFileClass *file);
 void ags_file_init(AgsFile *file);
 void ags_file_set_property(GObject *gobject,
@@ -131,7 +133,7 @@ ags_file_get_type (void)
     };
 
     ags_type_file = g_type_register_static(G_TYPE_OBJECT,
-					   "AgsFile\0",
+					   "AgsFile",
 					   &ags_file_info,
 					   0);
   }
@@ -161,11 +163,11 @@ ags_file_class_init(AgsFileClass *file)
    *
    * The assigned filename to open and read from.
    *
-   * Since: 0.5.0
+   * Since: 1.0.0
    */
-  param_spec = g_param_spec_string("filename\0",
-				   "filename to read or write\0",
-				   "The filename to read or write to.\0",
+  param_spec = g_param_spec_string("filename",
+				   i18n_pspec("filename to read or write"),
+				   i18n_pspec("The filename to read or write to"),
 				   NULL,
 				   G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
@@ -177,11 +179,11 @@ ags_file_class_init(AgsFileClass *file)
    *
    * The charset encoding to use.
    *
-   * Since: 0.5.0
+   * Since: 1.0.0
    */
-  param_spec = g_param_spec_string("encoding\0",
-				   "encoding to use\0",
-				   "The encoding of the XML document.\0",
+  param_spec = g_param_spec_string("encoding",
+				   i18n_pspec("encoding to use"),
+				   i18n_pspec("The encoding of the XML document"),
 				   NULL,
 				   G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
@@ -193,11 +195,11 @@ ags_file_class_init(AgsFileClass *file)
    *
    * The format of embedded audio data.
    *
-   * Since: 0.5.0
+   * Since: 1.0.0
    */
-  param_spec = g_param_spec_string("audio-format\0",
-				   "audio format to use\0",
-				   "The audio format used to embedded audio.\0",
+  param_spec = g_param_spec_string("audio-format",
+				   i18n_pspec("audio format to use"),
+				   i18n_pspec("The audio format used by embedded audio"),
 				   AGS_FILE_DEFAULT_AUDIO_FORMAT,
 				   G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
@@ -209,11 +211,11 @@ ags_file_class_init(AgsFileClass *file)
    *
    * The encoding to use for embedding audio data.
    *
-   * Since: 0.5.0
+   * Since: 1.0.0
    */
-  param_spec = g_param_spec_string("audio-encoding\0",
-				   "audio encoding to use\0",
-				   "The audio encoding used to embedded audio.\0",
+  param_spec = g_param_spec_string("audio-encoding",
+				   i18n_pspec("audio encoding to use"),
+				   i18n_pspec("The audio encoding used by embedded audio"),
 				   AGS_FILE_DEFAULT_AUDIO_ENCODING,
 				   G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
@@ -225,11 +227,11 @@ ags_file_class_init(AgsFileClass *file)
    *
    * The assigned xml-doc.
    * 
-   * Since: 0.7.3
+   * Since: 1.0.0
    */
-  param_spec = g_param_spec_pointer("xml-doc\0",
-				    "xml document of file\0",
-				    "The xml document assigned with file\0",
+  param_spec = g_param_spec_pointer("xml-doc",
+				    i18n_pspec("xml document of file"),
+				    i18n_pspec("The xml document assigned with file"),
 				    G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
 				  PROP_XML_DOC,
@@ -240,11 +242,11 @@ ags_file_class_init(AgsFileClass *file)
    *
    * The application context assigned with.
    *
-   * Since: 0.7.0
+   * Since: 1.0.0
    */
-  param_spec = g_param_spec_object("application-context\0",
-				   "application context of file\0",
-				   "The application context to write to file.\0",
+  param_spec = g_param_spec_object("application-context",
+				   i18n_pspec("application context of file"),
+				   i18n_pspec("The application context to write to file"),
 				   AGS_TYPE_APPLICATION_CONTEXT,
 				   G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
@@ -271,10 +273,10 @@ ags_file_class_init(AgsFileClass *file)
    * 
    * Open @file with appropriate filename.
    *
-   * Since: 0.5.0
+   * Since: 1.0.0
    */
   file_signals[OPEN] =
-    g_signal_new("open\0",
+    g_signal_new("open",
 		 G_TYPE_FROM_CLASS(file),
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(AgsFileClass, open),
@@ -292,10 +294,10 @@ ags_file_class_init(AgsFileClass *file)
    * 
    * Open @file from a buffer containing the file.
    *
-   * Since: 0.5.0
+   * Since: 1.0.0
    */
   file_signals[OPEN_FROM_DATA] =
-    g_signal_new("open-from-data\0",
+    g_signal_new("open-from-data",
 		 G_TYPE_FROM_CLASS(file),
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(AgsFileClass, open_from_data),
@@ -314,10 +316,10 @@ ags_file_class_init(AgsFileClass *file)
    * 
    * Open @file in read-write mode.
    *
-   * Since: 0.5.0
+   * Since: 1.0.0
    */
   file_signals[RW_OPEN] =
-    g_signal_new("rw-open\0",
+    g_signal_new("rw-open",
 		 G_TYPE_FROM_CLASS(file),
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(AgsFileClass, rw_open),
@@ -333,10 +335,10 @@ ags_file_class_init(AgsFileClass *file)
    * 
    * Write XML Document to disk.
    *
-   * Since: 0.5.0
+   * Since: 1.0.0
    */
   file_signals[WRITE] =
-    g_signal_new("write\0",
+    g_signal_new("write",
 		 G_TYPE_FROM_CLASS(file),
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(AgsFileClass, write),
@@ -345,7 +347,7 @@ ags_file_class_init(AgsFileClass *file)
 		 G_TYPE_NONE, 0);
 
   file_signals[WRITE_CONCURRENT] =
-    g_signal_new("write_concurrent\0",
+    g_signal_new("write_concurrent",
 		 G_TYPE_FROM_CLASS(file),
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(AgsFileClass, write_concurrent),
@@ -360,10 +362,10 @@ ags_file_class_init(AgsFileClass *file)
    * Resolve references and generate thus XPath expressions just
    * before writing to disk.
    *
-   * Since: 0.5.0
+   * Since: 1.0.0
    */
   file_signals[WRITE_RESOLVE] =
-    g_signal_new("write_resolve\0",
+    g_signal_new("write_resolve",
 		 G_TYPE_FROM_CLASS(file),
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(AgsFileClass, write_resolve),
@@ -377,10 +379,10 @@ ags_file_class_init(AgsFileClass *file)
    *
    * Read a XML document from disk with specified filename.
    * 
-   * Since: 0.5.0
+   * Since: 1.0.0
    */
   file_signals[READ] =
-    g_signal_new("read\0",
+    g_signal_new("read",
 		 G_TYPE_FROM_CLASS(file),
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(AgsFileClass, read),
@@ -395,10 +397,10 @@ ags_file_class_init(AgsFileClass *file)
    * Resolve XPath expressions to their counterpart the newly created
    * instances refering to.
    * 
-   * Since: 0.5.0
+   * Since: 1.0.0
    */
   file_signals[READ_RESOLVE] =
-    g_signal_new("read_resolve\0",
+    g_signal_new("read_resolve",
 		 G_TYPE_FROM_CLASS(file),
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(AgsFileClass, read_resolve),
@@ -412,10 +414,10 @@ ags_file_class_init(AgsFileClass *file)
    *
    * Hook after reading XML document to update or start the application.
    * 
-   * Since: 0.5.0
+   * Since: 1.0.0
    */
   file_signals[READ_START] =
-    g_signal_new("read_start\0",
+    g_signal_new("read_start",
 		 G_TYPE_FROM_CLASS(file),
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(AgsFileClass, read_start),
@@ -427,7 +429,7 @@ ags_file_class_init(AgsFileClass *file)
 GQuark
 ags_file_error_quark()
 {
-  return(g_quark_from_static_string("ags-file-error-quark\0"));
+  return(g_quark_from_static_string("ags-file-error-quark"));
 }
 
 void
@@ -644,7 +646,7 @@ ags_file_finalize(GObject *gobject)
  *
  * Returns: the md5 checksum
  *
- * Since: 0.4.0
+ * Since: 1.0.0
  */
 gchar*
 ags_file_str2md5(gchar *content, guint content_length)
@@ -666,7 +668,7 @@ ags_file_str2md5(gchar *content, guint content_length)
  *
  * Adds @id_ref to @file.
  * 
- * Since: 0.4.0
+ * Since: 1.0.0
  */
 void
 ags_file_add_id_ref(AgsFile *file, GObject *id_ref)
@@ -689,7 +691,7 @@ ags_file_add_id_ref(AgsFile *file, GObject *id_ref)
  * 
  * Returns: the matching #GObject
  *
- * Since: 0.4.0
+ * Since: 1.0.0
  */
 GObject*
 ags_file_find_id_ref_by_node(AgsFile *file, xmlNode *node)
@@ -721,7 +723,7 @@ ags_file_find_id_ref_by_node(AgsFile *file, xmlNode *node)
  * 
  * Returns: the matching #GObject
  *
- * Since: 0.4.0
+ * Since: 1.0.0
  */
 GObject*
 ags_file_find_id_ref_by_xpath(AgsFile *file, gchar *xpath)
@@ -732,7 +734,7 @@ ags_file_find_id_ref_by_xpath(AgsFile *file, gchar *xpath)
   xmlNode **node;
   guint i;
 
-  if(file == NULL || xpath == NULL || !g_str_has_prefix(xpath, "xpath=\0")){
+  if(file == NULL || xpath == NULL || !g_str_has_prefix(xpath, "xpath=")){
     g_message("invalid xpath: %s", xpath);
 
     return(NULL);
@@ -744,7 +746,7 @@ ags_file_find_id_ref_by_xpath(AgsFile *file, gchar *xpath)
   xpath_context = xmlXPathNewContext(file->doc);
 
   if(xpath_context == NULL) {
-    g_warning("Error: unable to create new XPath context\0");
+    g_warning("Error: unable to create new XPath context");
 
     return(NULL);
   }
@@ -753,7 +755,7 @@ ags_file_find_id_ref_by_xpath(AgsFile *file, gchar *xpath)
   xpath_object = xmlXPathEval(xpath, xpath_context);
 
   if(xpath_object == NULL) {
-    g_warning("Error: unable to evaluate xpath expression \"%s\"\0", xpath);
+    g_warning("Error: unable to evaluate xpath expression \"%s\"", xpath);
     xmlXPathFreeContext(xpath_context); 
 
     return(NULL);
@@ -768,7 +770,7 @@ ags_file_find_id_ref_by_xpath(AgsFile *file, gchar *xpath)
     }
   }
 
-  g_message("no xpath match: %s\0", xpath);
+  g_message("no xpath match: %s", xpath);
   
   return(NULL);
 }
@@ -782,7 +784,7 @@ ags_file_find_id_ref_by_xpath(AgsFile *file, gchar *xpath)
  * 
  * Returns: the matching #GObject
  *
- * Since: 0.4.0
+ * Since: 1.0.0
  */
 GObject*
 ags_file_find_id_ref_by_reference(AgsFile *file, gpointer ref)
@@ -812,7 +814,7 @@ ags_file_find_id_ref_by_reference(AgsFile *file, gpointer ref)
  *
  * Add @file_lookup for later invoking.
  *
- * Since: 0.4.0
+ * Since: 1.0.0
  */
 void
 ags_file_add_lookup(AgsFile *file, GObject *file_lookup)
@@ -834,7 +836,7 @@ ags_file_add_lookup(AgsFile *file, GObject *file_lookup)
  *
  * Add @file_launch for later invoking.
  *
- * Since: 0.4.0
+ * Since: 1.0.0
  */
 void
 ags_file_add_launch(AgsFile *file, GObject *file_launch)
@@ -861,13 +863,13 @@ ags_file_real_open(AgsFile *file,
   file->doc = xmlReadFile(file->filename, NULL, 0);
 
   if(file->doc == NULL){
-    g_warning("ags_file.c - failed to read XML document %s\0", file->filename);
+    g_warning("ags_file.c - failed to read XML document %s", file->filename);
 
     if(error != NULL){
       g_set_error(error,
 		  AGS_FILE_ERROR,
 		  AGS_FILE_ERROR_PARSER_FAILURE,
-		  "unable to parse document: %s\n\0",
+		  "unable to parse document: %s\n",
 		  file->filename);
     }
   }else{
@@ -883,7 +885,7 @@ ags_file_real_open(AgsFile *file,
  *
  * Opens the file specified by :filename property.
  *
- * Since: 0.4.0 
+ * Since: 1.0.0 
  */
 void
 ags_file_open(AgsFile *file,
@@ -910,13 +912,13 @@ ags_file_real_open_from_data(AgsFile *file,
   file->doc = xmlReadMemory(data, length, file->filename, NULL, 0);
 
   if(file->doc == NULL){
-    g_warning("ags_file.c - failed to read XML document %s\0", file->filename);
+    g_warning("ags_file.c - failed to read XML document %s", file->filename);
 
     if(error != NULL){
       g_set_error(error,
 		  AGS_FILE_ERROR,
 		  AGS_FILE_ERROR_PARSER_FAILURE,
-		  "unable to parse document from data: %s\n\0",
+		  "unable to parse document from data: %s\n",
 		  file->filename);
     }
   }else{
@@ -934,7 +936,7 @@ ags_file_real_open_from_data(AgsFile *file,
  *
  * Opens the file provided by @data.
  *
- * Since: 0.4.0 
+ * Since: 1.0.0 
  */
 void
 ags_file_open_from_data(AgsFile *file,
@@ -960,10 +962,10 @@ ags_file_real_rw_open(AgsFile *file,
     return;
   }
 
-  file->out = fopen(file->filename, "w+\0");
+  file->out = fopen(file->filename, "w+");
 
-  file->doc = xmlNewDoc("1.0\0");
-  file->root_node = xmlNewNode(NULL, "ags\0");
+  file->doc = xmlNewDoc("1.0");
+  file->root_node = xmlNewNode(NULL, "ags");
   xmlDocSetRootElement(file->doc, file->root_node);
 }
 
@@ -975,7 +977,7 @@ ags_file_real_rw_open(AgsFile *file,
  *
  * Opens the file specified by :filename property in read-write mode.
  *
- * Since: 0.4.0 
+ * Since: 1.0.0 
  */
 void
 ags_file_rw_open(AgsFile *file,
@@ -999,7 +1001,7 @@ ags_file_rw_open(AgsFile *file,
  *
  * Opens the file specified by @filename property.
  *
- * Since: 0.4.0 
+ * Since: 1.0.0 
  */
 void
 ags_file_open_filename(AgsFile *file,
@@ -1017,7 +1019,7 @@ ags_file_open_filename(AgsFile *file,
 
   error = NULL;
   g_object_set(file,
-	       "filename\0", filename,
+	       "filename", filename,
 	       NULL);
   ags_file_open(file,
 		&error);
@@ -1102,7 +1104,7 @@ ags_file_real_write(AgsFile *file)
   /* 
    * Dumping document to file
    */
-  //  xmlSaveFormatFileEnc(file->filename, file->doc, "UTF-8\0", 1);
+  //  xmlSaveFormatFileEnc(file->filename, file->doc, "UTF-8", 1);
   xmlDocDumpFormatMemoryEnc(file->doc, &(file->buffer), &size, file->encoding, TRUE);
 
   fwrite(file->buffer, size, sizeof(xmlChar), file->out);
@@ -1115,7 +1117,7 @@ ags_file_real_write(AgsFile *file)
  *
  * Write the XML document to disk.
  *
- * Since: 0.4.0
+ * Since: 1.0.0
  */
 void
 ags_file_write(AgsFile *file)
@@ -1148,8 +1150,8 @@ ags_file_real_write_concurrent(AgsFile *file)
 
   application_context = (AgsApplicationContext *) file->application_context;
 
-  file->doc = xmlNewDoc("1.0\0");
-  root_node = xmlNewNode(NULL, "ags\0");
+  file->doc = xmlNewDoc("1.0");
+  root_node = xmlNewNode(NULL, "ags");
   xmlDocSetRootElement(file->doc, root_node);
 
   parent = root_node;
@@ -1187,10 +1189,10 @@ ags_file_real_write_concurrent(AgsFile *file)
   /* 
    * Dumping document to file
    */
-  //  xmlSaveFormatFileEnc(file->filename, file->doc, "UTF-8\0", 1);
+  //  xmlSaveFormatFileEnc(file->filename, file->doc, "UTF-8", 1);
   xmlDocDumpFormatMemoryEnc(file->doc, &buffer, &size, file->encoding, TRUE);
 
-  file_out = fopen(file->filename, "w+\0");
+  file_out = fopen(file->filename, "w+");
   fwrite(buffer, size, sizeof(xmlChar), file_out);
   fflush(file_out);
   fclose(file_out);
@@ -1243,7 +1245,7 @@ ags_file_real_write_resolve(AgsFile *file)
  *
  * Resolve references to XPath expressions.
  *
- * Since: 0.4.0
+ * Since: 1.0.0
  */
 void
 ags_file_write_resolve(AgsFile *file)
@@ -1271,21 +1273,21 @@ ags_file_real_read(AgsFile *file)
   
   while(child != NULL){
     if(child->type == XML_ELEMENT_NODE){
-      if(!xmlStrncmp("ags-main\0",
+      if(!xmlStrncmp("ags-main",
 		     child->name,
 		     9)){
 	ags_file_read_application_context(file,
 					  child,
 					  (GObject **) &application_context);
-      }else if(!xmlStrncmp("ags-embedded-audio-list\0",
+      }else if(!xmlStrncmp("ags-embedded-audio-list",
 			   child->name,
 			   24)){
 	//TODO:JK: implement me
-      }else if(!xmlStrncmp("ags-file-link-list\0",
+      }else if(!xmlStrncmp("ags-file-link-list",
 			   child->name,
 			   19)){
 	//TODO:JK: implement me
-      }else if(!xmlStrncmp("ags-history\0",
+      }else if(!xmlStrncmp("ags-history",
 			   child->name,
 			   12)){
 	//TODO:JK: implement me
@@ -1298,11 +1300,11 @@ ags_file_real_read(AgsFile *file)
   /* resolve */
   ags_file_read_resolve(file);
   
-  g_message("XML file resolved\0");
+  g_message("XML file resolved");
 
   ags_connectable_connect(AGS_CONNECTABLE(application_context));
 
-  g_message("XML file connected\0");
+  g_message("XML file connected");
 
   /* start */
   ags_file_read_start(file);
@@ -1314,7 +1316,7 @@ ags_file_real_read(AgsFile *file)
  *
  * Read XML document from disk.
  *
- * Since: 0.4.0
+ * Since: 1.0.0
  */
 void
 ags_file_read(AgsFile *file)
@@ -1349,7 +1351,7 @@ ags_file_real_read_resolve(AgsFile *file)
  *
  * Resolve XPath expressions to references.
  *
- * Since: 0.4.0
+ * Since: 1.0.0
  */
 void
 ags_file_read_resolve(AgsFile *file)
@@ -1382,7 +1384,7 @@ ags_file_real_read_start(AgsFile *file)
  *
  * Update or start the application.
  *
- * Since: 0.4.0
+ * Since: 1.0.0
  */
 void
 ags_file_read_start(AgsFile *file)
@@ -1432,15 +1434,15 @@ ags_file_write_config(AgsFile *file, xmlNode *parent, GObject *config)
   id = ags_id_generator_create_uuid();
 
   node = xmlNewNode(NULL,
-		    "ags-config\0");
+		    "ags-config");
 
   ags_file_add_id_ref(file,
 		      g_object_new(AGS_TYPE_FILE_ID_REF,
-				   "application-context\0", file->application_context,
-				   "file\0", file,
-				   "node\0", node,
-				   "xpath\0", g_strdup_printf("xpath=//*[@id='%s']\0", id),
-				   "reference\0", config,
+				   "application-context", file->application_context,
+				   "file", file,
+				   "node", node,
+				   "xpath", g_strdup_printf("xpath=//*[@id='%s']", id),
+				   "reference", config,
 				   NULL));
 
   xmlNewProp(node,
@@ -1478,7 +1480,7 @@ ags_file_read_application_context(AgsFile *file, xmlNode *node, GObject **applic
   gchar *context;
 
   context = xmlGetProp(node,
-		       "context\0");
+		       "context");
 
   AGS_APPLICATION_CONTEXT_GET_CLASS(file->application_context)->register_types(AGS_APPLICATION_CONTEXT(file->application_context));
   AGS_APPLICATION_CONTEXT_GET_CLASS(file->application_context)->read(file,
@@ -1502,7 +1504,7 @@ ags_file_write_application_context(AgsFile *file, xmlNode *parent, GObject *appl
  *
  * Returns: a new #AgsFile
  *
- * Since: 0.3
+ * Since: 1.0.0
  */
 AgsFile*
 ags_file_new()
