@@ -34,6 +34,7 @@
 #include <ags/plugin/ags_lv2_preset.h>
 #include <ags/plugin/ags_lv2_event_manager.h>
 #include <ags/plugin/ags_lv2_log_manager.h>
+#include <ags/plugin/ags_lv2_option_manager.h>
 #include <ags/plugin/ags_lv2_uri_map_manager.h>
 #include <ags/plugin/ags_lv2_urid_manager.h>
 #include <ags/plugin/ags_lv2_worker_manager.h>
@@ -66,6 +67,7 @@
 #include <ags/audio/ags_playback.h>
 #include <ags/audio/ags_playback_domain.h>
 #include <ags/audio/ags_port.h>
+#include <ags/audio/ags_preset.h>
 #include <ags/audio/ags_recall_audio.h>
 #include <ags/audio/ags_recall_audio_run.h>
 #include <ags/audio/ags_recall_audio_signal.h>
