@@ -66,7 +66,7 @@ void ags_functional_editor_workflow_test_fill_all();
   "\n"						       \
   "[soundcard-0]\n"				       \
   "backend=alsa\n"                                     \
-  "device=hw:0,0\n"                                    \
+  "device=default\n"				       \
   "samplerate=44100\n"				       \
   "buffer-size=1024\n"				       \
   "pcm-channels=2\n"				       \
